"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const command_1 = require("@salesforce/command");
const core_1 = require("@salesforce/core");
var execSync = require("child_process").execSync;
// Initialize Messages with the current plugin directory
core_1.Messages.importMessagesDirectory(__dirname);
// Load the specific messages for this file. Messages from @salesforce/command, @salesforce/core,
// or any library that is using the messages framework can also be loaded this way.
// const messages = Messages.loadMessages('fonteva-sfdx', 'org');
class DevOrg extends command_1.SfdxCommand {
    createOrg(configFile, alias, targetUserName) {
        try {
            console.log('Creating Scratch Org');
            let installCommand = `sfdx force:org:create -f ${configFile} -d 30 --wait 15`;
            console.log(installCommand);
            execSync(installCommand, { stdio: [0, 1, 2] });
        }
        catch (err) {
            console.log(err);
        }
    }
    installDeps(packagename, isproduction, allcoredeps, targetUserName) {
        let installCommand = `sfdx fonteva:install:dependencies --targetusername=${targetUserName} -p ${packagename}`;
        console.log(installCommand);
        execSync(installCommand, { stdio: [0, 1, 2] });
    }
    runFLS(targetUserName) {
        let installCommand = `sfdx fonteva:fls:run --targetusername=${targetUserName}`;
        console.log(installCommand);
        execSync(installCommand, { stdio: [0, 1, 2] });
    }
    pushSource(targetUserName) {
        let installCommand = `sfdx fonteva:push --targetusername=${targetUserName}`;
        console.log(installCommand);
        execSync(installCommand, { stdio: [0, 1, 2] });
    }
    mapFullName(packageName) {
        let fullName = packageName.toLowerCase();
        switch (packageName.toLowerCase()) {
            case 'fdservice':
                fullName = 'FDService';
                break;
            case 'roeapi':
                fullName = 'RapidOrderEntry';
                break;
            case 'lte':
                fullName = 'LightningLens';
                break;
        }
        return fullName;
    }
    applyLayouts(targetUserName, packageName) {
        let fullName = this.mapFullName(packageName);
        let installCommand = `sfdx fonteva:layouts:apply --targetusername=${targetUserName} -p ${fullName}`;
        console.log(installCommand);
        execSync(installCommand, { stdio: [0, 1, 2] });
    }
    async run() {
        this.createOrg(this.flags.scratchorgconfig, this.flags.alias, this.flags.username);
        this.installDeps(this.flags.packagename, this.flags.isproduction, this.flags.allcoredeps, this.flags.username);
        this.runFLS(this.flags.username);
        if (this.flags.pushsource) {
            this.pushSource(this.flags.username);
        }
        this.runFLS(this.flags.username);
        this.applyLayouts(this.flags.username, this.flags.packagename);
        return {};
    }
}
exports.default = DevOrg;
DevOrg.description = 'Setup an org for development. Deploy dependent packages, FLS, and deploy code.';
DevOrg.examples = [
    `$ sfdx install:dependencies --targetusername myOrg@example.com --targetdevhubusername devhub@org.com
  Hello world! This is org: MyOrg and I will be around until Tue Mar 20 2018!
  My hub org id is: 00Dxx000000001234
  `
];
DevOrg.args = [];
DevOrg.flagsConfig = {
    packagename: command_1.flags.string({ char: 'p', description: 'Package to install deps for', required: true }),
    username: command_1.flags.string({ char: 't', description: 'target user name', required: true }),
    scratchorgconfig: command_1.flags.string({ char: 's', description: 'Scratch Org Config', required: true }),
    pushsource: command_1.flags.boolean({ char: 'h', description: 'Push Source' }),
    isproduction: command_1.flags.boolean({ char: 'd', description: 'If Is Production' }),
    allcoredeps: command_1.flags.boolean({ char: 'c', description: 'All Core Deps' })
};
// Comment this out if your command does not require an org username
DevOrg.requiresUsername = false;
// Comment this out if your command does not support a hub org username
DevOrg.supportsDevhubUsername = true;
// Set this to true if your command requires a project workspace; 'requiresProject' is false by default
DevOrg.requiresProject = false;
//# sourceMappingURL=devorg.js.map