"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const command_1 = require("@salesforce/command");
const core_1 = require("@salesforce/core");
const utils_1 = require("../../../shared/utils");
const fs = require("fs-extra");
const swap_1 = require("../../../shared/swap");
const execSync = require("child_process").execSync;
const rimraf = require('rimraf');
const path = require('path');
// Initialize Messages with the current plugin directory
core_1.Messages.importMessagesDirectory(__dirname);
// Load the specific messages for this file. Messages from @salesforce/command, @salesforce/core,
// or any library that is using the messages framework can also be loaded this way.
// const messages = Messages.loadMessages('fonteva-sfdx', 'org');
class Layouts extends command_1.SfdxCommand {
    async deployCommunity(targetUserName) {
        let directory = path.normalize(__dirname + '/../../../../layouts');
        let currentDirectory = path.normalize(process.cwd());
        fs.removeSync(path.normalize(currentDirectory + '/tmp_community'));
        fs.copySync(path.normalize(directory + '/LTEDev'), path.normalize(currentDirectory + '/tmp_community'));
        const sourcePath = path.normalize(`${currentDirectory}/tmp_community/src`);
        const communityCommand = `sfdx force:source:deploy -p "${sourcePath}" --targetusername ${targetUserName} --wait 15`;
        const orgNamespace = utils_1.getOrgNamespace(targetUserName);
        const conn = this.org.getConnection();
        let portalIsConfigured = false;
        const portal = await conn.metadata.list({ type: 'ExperienceBundle', folder: 'routes' });
        // @ts-ignore
        if (portal && portal.fullName) {
            const eb = await conn.metadata.read('ExperienceBundle', 'Member_Portal1');
            // @ts-ignore
            portalIsConfigured = eb && eb.experienceResources && eb.experienceResources.experienceResource
                // @ts-ignore
                && eb.experienceResources.experienceResource.some(er => er.fileName === 'orderSummary');
        }
        // leaving below in case we ever need to do more verification
        const communities = await conn.queryAll('Select Id From Network');
        if (communities.records.length === 0) {
            console.error('No Salesforce Communities Configured. Please create a community with the name "Member Portal" of type "Built it Yourself"');
            console.error('Then enable ExperienceBundle under Setup > Communities Settings');
        }
        // @ts-ignore
        if (!portalIsConfigured) {
            console.log(`Configuring community and creating ${orgNamespace}__Site__c & ${orgNamespace}__Menu_Item__c records`);
            await conn.sobject(`${orgNamespace}__Menu_Item__c`).find({}).destroy();
            await conn.sobject(`${orgNamespace}__Site__c`).find({}).destroy();
            await swap_1.doSwapInPlace(path.normalize('tmp_community'), 'LTE', orgNamespace);
            const sitesTreeExportFilePath = path.normalize(`${currentDirectory}/tmp_community/lte-sites-tree-export.json`);
            const sitesImport = `sfdx force:data:tree:import -u ${targetUserName} -f "${sitesTreeExportFilePath}"`;
            execSync(sitesImport, { stdio: [0, 1, 2] });
            execSync(communityCommand, { stdio: [0, 1, 2] });
        }
        else {
            console.log('LTE Dev Org community is already configured (and errors if configured 2x)');
        }
        rimraf.sync(path.normalize('./tmp_community'));
    }
    async run() {
        await this.deployCommunity(this.flags.targetusername);
        return {};
    }
}
exports.default = Layouts;
Layouts.description = 'Configure the community in an LTE DevOrg';
Layouts.args = [];
// Comment this out if your command does not require an org username
Layouts.requiresUsername = true;
// Comment this out if your command does not support a hub org username
Layouts.supportsDevhubUsername = true;
// Set this to true if your command requires a project workspace; 'requiresProject' is false by default
Layouts.requiresProject = false;
//# sourceMappingURL=apply.js.map