"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const command_1 = require("@salesforce/command");
const execSync = require("child_process").execSync;
class Deploy extends command_1.SfdxCommand {
    runCmd(cmd) {
        console.log(cmd);
        execSync(cmd, { stdio: [0, 1, 2] });
    }
    async run() {
        const deployArgs = this.flags.metadata ? ` --metadata ${this.flags.metadata}` : '' +
            this.flags.sourcepath ? ` --sourcepath ${this.flags.sourcepath}` : '' +
            this.flags.manifest ? ` --manifest ${this.flags.manifest}` : '' +
            this.flags.validateddeployrequestid ? ` --validateddeployrequestid ${this.flags.validateddeployrequestid}` : '';
        this.runCmd(`sfdx fonteva:sfpm:install -d`);
        this.runCmd(`sfdx force:source:deploy --targetusername ${this.flags.targetusername} ${deployArgs}`);
        return { foo: 'bar' };
    }
}
exports.default = Deploy;
Deploy.description = 'Meta-target for installs. Runs sfpm, then deploy';
Deploy.examples = [];
Deploy.args = [];
Deploy.flagsConfig = {
    // flag with a value (-n, --name=VALUE)
    // name: flags.string({char: 'n', description: messages.getMessage('nameFlagDescription')}),
    // force: flags.boolean({char: 'f', description: messages.getMessage('forceFlagDescription')})
    metadata: command_1.flags.string({ char: 'm', description: 'comma-separated list of metadata component names' }),
    sourcepath: command_1.flags.string({ char: 'p', description: 'comma-separated list of paths to the local source files to deploy' }),
    manifest: command_1.flags.string({ char: 'x', description: 'file path for manifest (package.xml) of components to deploy' }),
    validateddeployrequestid: command_1.flags.string({ char: 'q', description: 'request ID of the validated deployment to run a Quick Deploy' })
};
// Comment this out if your command does not require an org username
Deploy.requiresUsername = true;
// Comment this out if your command does not support a hub org username
Deploy.supportsDevhubUsername = false;
// Set this to true if your command requires a project workspace; 'requiresProject' is false by default
Deploy.requiresProject = false;
//# sourceMappingURL=deploy.js.map