"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const command_1 = require("@salesforce/command");
const core_1 = require("@salesforce/core");
const needle = require("needle");
const utils_1 = require("../../../shared/utils");
// Initialize Messages with the current plugin directory
core_1.Messages.importMessagesDirectory(__dirname);
// Load the specific messages for this file. Messages from @salesforce/command, @salesforce/core,
// or any library that is using the messages framework can also be loaded this way.
// const messages = Messages.loadMessages('fonteva-sfdx', 'org');
class FLSRun extends command_1.SfdxCommand {
    async run() {
        console.log('Running a query to force a refresh of your OAUTH token');
        console.log('---- ----- ---- ---- -----');
        utils_1.echoCmdAndRun(`sfdx force:data:soql:query -q "SELECT Id FROM Contact Limit 1" -u ${this.flags.targetusername} --json`);
        // this.org is guaranteed because requiresUsername=true, as opposed to supportsUsername
        const conn = this.org.getConnection();
        let profile = 'Admin';
        if (this.flags.profile) {
            profile = this.flags.profile;
        }
        const url = `http://sparktool-staging.herokuapp.com/api/flsforbuild?profile=` + profile;
        needle('post', url, {
            accessToken: conn.accessToken,
            instanceUrl: conn.instanceUrl,
            username: this.flags.targetusername
        }, function (error, response, body) {
            const interval = setInterval(function () {
                needle('get', 'http://sparktool-staging.herokuapp.com/api/jobstatus?id=' + body.message, function (childError, childResponse, childBody) {
                    if (childBody.message !== 'In Progress') {
                        clearInterval(interval);
                        if (childBody.message === 'Success') {
                            console.log('FLS Ran Successfully');
                        }
                        else {
                            console.log('FLS Failed');
                            console.log(`message = ${childBody.message}`);
                        }
                    }
                });
            }, 250);
        });
        return {};
    }
}
exports.default = FLSRun;
FLSRun.description = 'Run the FLS utility, granting access to Fonteva custom objects.';
FLSRun.examples = [
    `$ sfdx fonteva:fls:run --targetusername=myOrg@example.com`
];
FLSRun.args = [];
FLSRun.flagsConfig = {
    profile: command_1.flags.string({ char: 'p', description: 'Profile', required: false })
};
// Comment this out if your command does not require an org username
FLSRun.requiresUsername = true;
// Comment this out if your command does not support a hub org username
// protected static supportsDevhubUsername = true;
// Set this to true if your command requires a project workspace; 'requiresProject' is false by default
FLSRun.requiresProject = false;
//# sourceMappingURL=run.js.map