"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const command_1 = require("@salesforce/command");
const core_1 = require("@salesforce/core");
const utils_1 = require("../../../shared/utils");
const fs = require("fs-extra");
const swap_1 = require("../../../shared/swap");
const execSync = require("child_process").execSync;
const mergeDirs = require('merge-dirs').default;
const path = require('path');
// Initialize Messages with the current plugin directory
core_1.Messages.importMessagesDirectory(__dirname);
// Load the specific messages for this file. Messages from @salesforce/command, @salesforce/core,
// or any library that is using the messages framework can also be loaded this way.
// const messages = Messages.loadMessages('fonteva-sfdx', 'org');
class Layouts extends command_1.SfdxCommand {
    static async deployLayouts(packageName, targetUserName) {
        let directory = path.normalize(__dirname + '/../../../../layouts');
        let currentDirectory = path.normalize(process.cwd());
        fs.removeSync(path.normalize(currentDirectory + '/tmp'));
        fs.copySync(path.normalize(directory + '/' + packageName), path.normalize(currentDirectory + '/tmp'));
        const sourcePath = path.normalize(`${currentDirectory}/tmp/src`);
        const layoutCommand = `sfdx force:mdapi:deploy -d "${sourcePath}" --targetusername ${targetUserName} --wait 15`;
        const ns = utils_1.getOrgNamespace(targetUserName);
        let lteDevOrg = false;
        if (packageName === 'LightningLens' && ns === 'LTE') {
            // community and layouts need to be deployed at the same time
            mergeDirs(path.normalize(directory + '/LTEScratch'), path.normalize(currentDirectory + '/tmp'));
        }
        else {
            lteDevOrg = packageName === 'LightningLens';
            const prodNamespace = lteDevOrg ? 'LTE'
                : packageName === 'RapidOrderEntry' ? 'ROEApi'
                    : packageName;
            await swap_1.doSwapInPlace('tmp', prodNamespace, ns);
        }
        console.log(layoutCommand);
        execSync(layoutCommand, { stdio: [0, 1, 2] });
        fs.removeSync(path.normalize(currentDirectory + '/tmp'));
        if (lteDevOrg) {
            const communityCmd = `sfdx fonteva:community:apply -u ${targetUserName}`;
            execSync(communityCmd, { stdio: [0, 1, 2] });
        }
    }
    async run() {
        await Layouts.deployLayouts(this.flags.packagename, this.flags.targetusername);
        return {};
    }
}
exports.default = Layouts;
Layouts.description = 'Apply useful layouts for Fonteva custom objects.';
Layouts.examples = [
    `$ sfdx install:dependencies --targetusername myOrg@example.com --targetdevhubusername devhub@org.com
  Hello world! This is org: MyOrg and I will be around until Tue Mar 20 2018!
  My hub org id is: 00Dxx000000001234
  `
];
Layouts.args = [];
Layouts.flagsConfig = {
    packagename: command_1.flags.string({ char: 'p', description: 'Package to install layouts for', required: true }),
};
// Comment this out if your command does not require an org username
Layouts.requiresUsername = true;
// Comment this out if your command does not support a hub org username
Layouts.supportsDevhubUsername = true;
// Set this to true if your command requires a project workspace; 'requiresProject' is false by default
Layouts.requiresProject = false;
//# sourceMappingURL=apply.js.map