"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const command_1 = require("@salesforce/command");
const core_1 = require("@salesforce/core");
const utils_1 = require("../../../shared/utils");
const swap_1 = require("../../../shared/swap");
const bb = require('bluebird');
const fs = bb.promisifyAll(require('fs-extra'));
const convert = require('xml-js');
// Initialize Messages with the current plugin directory
core_1.Messages.importMessagesDirectory(__dirname);
class Swap extends command_1.SfdxCommand {
    async run() {
        if (!this.flags.targetusername && !this.args.ns) {
            console.error('Either supply the targetusername (-u) or a namespace to swap to');
            return;
        }
        if (!fs.existsSync(`./src/package.xml`)) {
            const argOrUser = this.flags.targetusername ? `-u ${this.flags.targetusername}` : this.args.ns;
            const unpackaged = this.flags.unpackaged ? '--unpackaged' : '';
            utils_1.echoCmdAndRun(`sfdx fonteva:ns:swapSfdx ${argOrUser} ${unpackaged}`);
            return {};
        }
        const targetNamespace = this.args.ns || utils_1.getOrgNamespace(this.flags.targetusername);
        console.log(`swapping to ${targetNamespace}`);
        const packxml = convert.xml2js(fs.readFileSync(`src/package.xml`), { compact: true });
        await swap_1.doSwap('src', packxml.Package.namespacePrefix._text, targetNamespace);
        return {};
    }
}
exports.default = Swap;
Swap.description = 'Do a namespace swap for a source-format project';
Swap.examples = [
    `$ sfdx fonteva:ns:swap qa1234 // swaps to namespace "qa1234"`,
    `$ sfdx fonteva:ns:swap -u devorg123 // connects to the org specified, determines the namespace, then swaps`
];
Swap.args = [{
        name: 'ns',
        required: false,
        description: "The namespace to swap to (takes precedence over the detected org namespace)"
    }];
Swap.flagsConfig = {
    unpackaged: command_1.flags.boolean({ description: 'Deploy unpackaged code, not the main codebase.', required: false })
};
Swap.supportsUsername = true;
// Set this to true if your command requires a project workspace; 'requiresProject' is false by default
Swap.requiresProject = false;
//# sourceMappingURL=swap.js.map