"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const command_1 = require("@salesforce/command");
const core_1 = require("@salesforce/core");
const utils_1 = require("../../../shared/utils");
const swap_1 = require("../../../shared/swap");
// Initialize Messages with the current plugin directory
core_1.Messages.importMessagesDirectory(__dirname);
class SwapSfdx extends command_1.SfdxCommand {
    async run() {
        if (!this.flags.targetusername && !this.args.ns) {
            console.error('Either supply the targetusername (-u) or a namespace to swap to');
            return;
        }
        const targetNamespace = this.args.ns || utils_1.getOrgNamespace(this.flags.targetusername);
        console.log(`swappping to ${targetNamespace}`);
        const projectJson = await this.project.retrieveSfdxProjectJson();
        const sourcePath = this.flags.unpackaged
            ? 'unpackaged/developer'
            // @ts-ignore
            : projectJson.get('packageDirectories').find(dir => dir.default).path;
        const namespace = projectJson.get('namespace');
        // @ts-ignore
        await swap_1.doSwap(sourcePath, namespace, targetNamespace);
        return {};
    }
}
exports.default = SwapSfdx;
SwapSfdx.description = 'Do a namespace swap for a source-format project';
SwapSfdx.examples = [
    `$ sfdx fonteva:ns:swap qa1234 // swaps to namespace "qa1234"`,
    `$ sfdx fonteva:ns:swap -u devorg123 // connects to the org specified, determines the namespace, then swaps`
];
SwapSfdx.args = [{
        name: 'ns',
        required: false,
        description: "The namespace to swap to (takes precedence over the detected org namespace)"
    }];
SwapSfdx.flagsConfig = {
    unpackaged: command_1.flags.boolean({ description: 'Deploy unpackaged code, not the main codebase.', required: false })
};
SwapSfdx.supportsUsername = true;
// Set this to true if your command requires a project workspace; 'requiresProject' is false by default
SwapSfdx.requiresProject = true;
//# sourceMappingURL=swapSfdx.js.map