"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const command_1 = require("@salesforce/command");
const core_1 = require("@salesforce/core");
const utils_1 = require("../../shared/utils");
const bb = require('bluebird');
const fs = bb.promisifyAll(require('fs-extra'));
const rimraf = require('rimraf');
// Initialize Messages with the current plugin directory
core_1.Messages.importMessagesDirectory(__dirname);
class SwapAndDeploy extends command_1.SfdxCommand {
    async run() {
        if (fs.existsSync("./package.json")) {
            utils_1.echoCmdAndRun(`sfdx fonteva:sfpm:install -d`);
        }
        const ns = this.args.ns || '';
        const unpackaged = this.flags.unpackaged ? '--unpackaged' : '';
        utils_1.echoCmdAndRun(`sfdx fonteva:ns:swap -u ${this.flags.targetusername} ${ns} ${unpackaged}`);
        if (fs.existsSync(`./src/package.xml`)) {
            utils_1.echoCmdAndRun(`sfdx force:mdapi:deploy -u ${this.flags.targetusername} -d ./tmp -w 20`);
        }
        else {
            utils_1.echoCmdAndRun(`sfdx force:source:deploy -u ${this.flags.targetusername} -p ./tmp`);
        }
        rimraf.sync('./tmp');
        return {};
    }
}
exports.default = SwapAndDeploy;
SwapAndDeploy.description = 'Do a namespace swap for a source-format project and deploy';
SwapAndDeploy.examples = [
    `$ sfdx fonteva:swapAndDeploy -u devorg123 // connects to the org specified, determines the namespace, swaps namespace into a temp folder, then deploys`
];
SwapAndDeploy.args = [];
SwapAndDeploy.flagsConfig = {
    unpackaged: command_1.flags.boolean({ description: 'Deploy unpackaged code, not the main codebase.', required: false })
};
SwapAndDeploy.requiresUsername = true;
// Set this to true if your command requires a project workspace; 'requiresProject' is false by default
SwapAndDeploy.requiresProject = false;
//# sourceMappingURL=swapAndDeploy.js.map